# modifying the dockerinit binary breaks the SHA1 sum check by docker
%global __os_install_post %{_rpmconfigdir}/brp-compress
%global dist_version 18.06.1
%global moby_version %{dist_version}-ce

# binaries and unitfiles are currently called 'docker'
# to match with upstream supplied packages

%global origname docker
%global newname moby
%global service_name %{origname}


# docker builds in a checksum of dockerinit into docker,
# so stripping the binaries breaks docker
%global debug_package %{nil}
%global provider github
%global provider_tld com
%global project docker
%global repo %{project}
%global import_path %{provider}.%{provider_tld}/%{project}/%{repo}-ce

#debuginfo not supported with Go
%global gopath  %{_libdir}/golang
%define gosrc %{gopath}/src/pkg/%{import_path}

%global commit      e68fc7a215d7133c34aa18e3b72b4a21fd0c6136
%global shortcommit %(c=%{commit}; echo ${c:0:7})

# docker-proxy / libnetwork  
%global git_libnetwork https://github.com/%{service_name}/libnetwork
%global commit_libnetwork e73627b4f4fea8c3fa92fbb928a9f865d2aa3330
%global shortcommit_libnetwork %(c=%{commit_libnetwork}; echo ${c:0:7})

# tini
%global git_tini https://github.com/krallin/tini
%global commit_tini fec3683b971d9c3ef73f284f176672c44b448662
%global shortcommit_tini %(c=%{commit_tini}; echo ${c:0:7})

Name:           docker
#Version:       1.3.1.git%{shortcommit}
Version:        %{dist_version}
%define subrel 2
Release:        %mkrel 1
Summary:        Automates deployment of containerized applications
License:        ASL 2.0
Group:			System/Configuration

URL:            http://www.docker.com
# only x86_64 for now: https://github.com/docker/docker/issues/136
#ExclusiveArch:  x86_64
Source0:        https://%{import_path}/archive/v%{moby_version}.tar.gz

Source1: %{repo}.service
Source2: %{repo}.sysconfig
Source3: %{repo}-storage.sysconfig
Source4: %{repo}-logrotate.sh
Source5: README.%{repo}-logrotate
Source6: %{repo}-network.sysconfig
Source7: %{repo}.socket
Source8: %{repo}-network-cleanup.sh

Source10:        %{git_libnetwork}/archive/%{commit_libnetwork}.tar.gz#/libnetwork-%{shortcommit_libnetwork}.tar.gz
Source11: %{git_tini}/archive/%{commit_tini}.tar.gz#/tini-%{shortcommit_tini}.tar.gz

# For CVE-2018-20699
Patch0: 11e17d3b79bc450a52d5e1dd1c1444f7ebe5f751.patch

#Patch1: go-1.12.0.patch

BuildRequires:  gcc
BuildRequires:  glibc-devel
BuildRequires:  glibc-static-devel
BuildRequires:  cmake

# ensure build uses golang 1.10 or above
BuildRequires:  golang >= 1.10

BuildRequires:  pkgconfig(sqlite3)

BuildRequires:  golang-net-devel
BuildRequires:  go-md2man
BuildRequires:  pkgconfig(devmapper)
BuildRequires:  btrfs-devel
BuildRequires:  libltdl-devel
BuildRequires:  pkgconfig(systemd)
Requires:       systemd-units

# With docker >= 1.11 you now need containerd (and runC as a dep)
Requires:		docker-containerd >= 1.1.0

# need xz to work with ubuntu images
# https://bugzilla.redhat.com/show_bug.cgi?id=1045220
Requires:       xz

# https://bugzilla.redhat.com/show_bug.cgi?id=1035436
# this won't be needed for rhel7+
Requires:       bridge-utils
Requires:       lxc
# The auplink command is required for network setup in ctn
Requires:       aufs-tools

Requires:       iptables

# https://bugzilla.redhat.com/show_bug.cgi?id=1034919
# No longer needed in Fedora because of libcontainer
Requires:       libcgroup
Provides:       lxc-docker = %{version}

Obsoletes: docker-io < 1.2.0-8
Provides: docker-io = %{version}-%{release}
Obsoletes: docker-swarm
Provides: docker-swarm = %{version}-%{release}

%description
Docker is an open-source engine that automates the deployment of any
application as a lightweight, portable, self-sufficient container that will
run virtually anywhere.

Docker containers can encapsulate any payload, and will run consistently on
and between virtually any server. The same container that a developer builds
and tests on a laptop will run at scale, in production*, on VMs, bare-metal
servers, OpenStack clusters, public instances, or combinations of the above.

%package devel
BuildRequires:  golang >= 1.4
Requires:       golang >= 1.4
Requires:       docker-pkg-devel
Summary:        A golang registry for global request variables (source libraries)
Provides: %{repo}-pkg-devel = %{version}-%{release}
Provides: golang(%{import_path}) = %{version}-%{release}
Provides: golang(%{import_path}/builder) = %{version}-%{release}
Provides: golang(%{import_path}/builder/parser) = %{version}-%{release}
Provides: golang(%{import_path}/builder/parser/dumper) = %{version}-%{release}
Provides: golang(%{import_path}/builder/command) = %{version}-%{release}
Provides: golang(%{import_path}/nat) = %{version}-%{release}
Provides: golang(%{import_path}/utils) = %{version}-%{release}
Provides: golang(%{import_path}/integration-cli) = %{version}-%{release}
Provides: golang(%{import_path}/trust) = %{version}-%{release}
Provides: golang(%{import_path}/events) = %{version}-%{release}
Provides: golang(%{import_path}/volumes) = %{version}-%{release}
Provides: golang(%{import_path}/engine) = %{version}-%{release}
Provides: golang(%{import_path}/registry) = %{version}-%{release}
Provides: golang(%{import_path}/registry/v2) = %{version}-%{release}
Provides: golang(%{import_path}/api) = %{version}-%{release}
Provides: golang(%{import_path}/api/client) = %{version}-%{release}
Provides: golang(%{import_path}/api/stats) = %{version}-%{release}
Provides: golang(%{import_path}/api/server) = %{version}-%{release}
Provides: golang(%{import_path}/opts) = %{version}-%{release}
Provides: golang(%{import_path}/builtins) = %{version}-%{release}
Provides: golang(%{import_path}/runconfig) = %{version}-%{release}
Provides: golang(%{import_path}/docker) = %{version}-%{release}
Provides: golang(%{import_path}/contrib/docker-device-tool) = %{version}-%{release}
Provides: golang(%{import_path}/contrib/host-integration) = %{version}-%{release}
Provides: golang(%{import_path}/daemon) = %{version}-%{release}
Provides: golang(%{import_path}/daemon/graphdriver) = %{version}-%{release}
Provides: golang(%{import_path}/daemon/graphdriver/devmapper) = %{version}-%{release}
Provides: golang(%{import_path}/daemon/graphdriver/aufs) = %{version}-%{release}
Provides: golang(%{import_path}/daemon/graphdriver/overlay) = %{version}-%{release}
Provides: golang(%{import_path}/daemon/graphdriver/vfs) = %{version}-%{release}
Provides: golang(%{import_path}/daemon/graphdriver/btrfs) = %{version}-%{release}
Provides: golang(%{import_path}/daemon/graphdriver/graphtest) = %{version}-%{release}
Provides: golang(%{import_path}/daemon/networkdriver) = %{version}-%{release}
Provides: golang(%{import_path}/daemon/networkdriver/ipallocator) = %{version}-%{release}
Provides: golang(%{import_path}/daemon/networkdriver/portmapper) = %{version}-%{release}
Provides: golang(%{import_path}/daemon/networkdriver/bridge) = %{version}-%{release}
Provides: golang(%{import_path}/daemon/networkdriver/portallocator) = %{version}-%{release}
Provides: golang(%{import_path}/daemon/execdriver) = %{version}-%{release}
Provides: golang(%{import_path}/daemon/execdriver/execdrivers) = %{version}-%{release}
Provides: golang(%{import_path}/daemon/execdriver/lxc) = %{version}-%{release}
Provides: golang(%{import_path}/daemon/execdriver/native) = %{version}-%{release}
Provides: golang(%{import_path}/daemon/execdriver/native/template) = %{version}-%{release}
Provides: golang(%{import_path}/pkg/devicemapper) = %{version}-%{release}
Provides: golang(%{import_path}/pkg/units) = %{version}-%{release}
Provides: golang(%{import_path}/pkg/chrootarchive) = %{version}-%{release}
Provides: golang(%{import_path}/pkg/mount) = %{version}-%{release}
Provides: golang(%{import_path}/pkg/systemd) = %{version}-%{release}
Provides: golang(%{import_path}/pkg/parsers) = %{version}-%{release}
Provides: golang(%{import_path}/pkg/parsers/kernel) = %{version}-%{release}
Provides: golang(%{import_path}/pkg/parsers/operatingsystem) = %{version}-%{release}
Provides: golang(%{import_path}/pkg/parsers/filters) = %{version}-%{release}
Provides: golang(%{import_path}/pkg/broadcastwriter) = %{version}-%{release}
Provides: golang(%{import_path}/pkg/stdcopy) = %{version}-%{release}
Provides: golang(%{import_path}/pkg/proxy) = %{version}-%{release}
Provides: golang(%{import_path}/pkg/promise) = %{version}-%{release}
Provides: golang(%{import_path}/pkg/pools) = %{version}-%{release}
Provides: golang(%{import_path}/pkg/system) = %{version}-%{release}
Provides: golang(%{import_path}/pkg/fileutils) = %{version}-%{release}
Provides: golang(%{import_path}/pkg/mflag) = %{version}-%{release}
Provides: golang(%{import_path}/pkg/mflag/example) = %{version}-%{release}
Provides: golang(%{import_path}/pkg/timeutils) = %{version}-%{release}
Provides: golang(%{import_path}/pkg/ioutils) = %{version}-%{release}
Provides: golang(%{import_path}/pkg/pubsub) = %{version}-%{release}
Provides: golang(%{import_path}/pkg/signal) = %{version}-%{release}
Provides: golang(%{import_path}/pkg/listenbuffer) = %{version}-%{release}
Provides: golang(%{import_path}/pkg/version) = %{version}-%{release}
Provides: golang(%{import_path}/pkg/httputils) = %{version}-%{release}
Provides: golang(%{import_path}/pkg/urlutil) = %{version}-%{release}
Provides: golang(%{import_path}/pkg/sysinfo) = %{version}-%{release}
Provides: golang(%{import_path}/pkg/archive) = %{version}-%{release}
Provides: golang(%{import_path}/pkg/iptables) = %{version}-%{release}
Provides: golang(%{import_path}/pkg/tailfile) = %{version}-%{release}
Provides: golang(%{import_path}/pkg/graphdb) = %{version}-%{release}
Provides: golang(%{import_path}/pkg/tarsum) = %{version}-%{release}
Provides: golang(%{import_path}/pkg/namesgenerator) = %{version}-%{release}
Provides: golang(%{import_path}/pkg/jsonlog) = %{version}-%{release}
Provides: golang(%{import_path}/pkg/testutils) = %{version}-%{release}
Provides: golang(%{import_path}/pkg/truncindex) = %{version}-%{release}
Provides: golang(%{import_path}/pkg/homedir) = %{version}-%{release}
Provides: golang(%{import_path}/pkg/symlink) = %{version}-%{release}
Provides: golang(%{import_path}/pkg/networkfs/resolvconf) = %{version}-%{release}
Provides: golang(%{import_path}/pkg/networkfs/etchosts) = %{version}-%{release}
Provides: golang(%{import_path}/pkg/term) = %{version}-%{release}
Provides: golang(%{import_path}/pkg/reexec) = %{version}-%{release}
Provides: golang(%{import_path}/integration) = %{version}-%{release}
Provides: golang(%{import_path}/links) = %{version}-%{release}
Provides: golang(%{import_path}/image) = %{version}-%{release}

%description devel
This is the source libraries for docker.

%package fish-completion
Summary: fish completion files for Docker
Requires: %{repo} = %{version}-%{release}
Requires: fish
Provides: %{repo}-io-fish-completion = %{version}-%{release}

%description fish-completion
This package installs %{summary}.

%package logrotate
Summary: cron job to run logrotate on Docker containers
Requires: %{repo} = %{version}-%{release}
Provides: %{repo}-io-logrotate = %{version}-%{release}

%description logrotate
This package installs %{summary}. logrotate is assumed to be installed on
containers for this to work, failures are silently ignored.

%package unit-test
Summary: %{summary} - for running unit tests

%description unit-test
%{summary} - for running unit tests

%package vim
Summary: vim syntax highlighting files for Docker
Requires: %{repo} = %{version}-%{release}
Requires: vim
Provides: %{repo}-io-vim = %{version}-%{release}

%description vim
This package installs %{summary}.

%package zsh-completion
Summary: zsh completion files for Docker
Requires: %{repo} = %{version}-%{release}
Requires: zsh
Provides: %{repo}-io-zsh-completion = %{version}-%{release}

%description zsh-completion
This package installs %{summary}.

%package nano
Summary: nano syntax highlighting files for Moby
Requires: %{name} = %{version}-%{release}
Requires: nano

%description nano
This package installs %{summary}.

%prep
#%setup -q -n docker-%{commit}
%setup -q -n docker-ce-%{moby_version}
%autopatch -p1

# here keep the new line above otherwise autosetup fails when applying patch
cp %{SOURCE5} .
#sed -i 's/$/%{?dist}/' VERSION

tar xzf %{SOURCE10} \
   libnetwork-%{commit_libnetwork}/cmd/proxy

# untar tini
tar zxf %{SOURCE11}

%build
export DOCKER_GITCOMMIT="%{shortcommit}"
#export DOCKER_GITCOMMIT="%{shortcommit}/%{version}"

# Preparing GOPATH so that the client is visible to the compiler
mkdir -p src/github.com/docker/
ln -s $(pwd)/components/cli $(pwd)/src/github.com/docker/cli
GOPATH=$GOPATH:$(pwd)

# build docker-proxy / libnetwork
pushd libnetwork-%{commit_libnetwork}
mkdir -p src/github.com/%{service_name}
mkdir -p vendor
ln -s $(pwd) src/github.com/%{service_name}/libnetwork
ln -s $(pwd)/../components/engine/vendor vendor/src
export GOPATH=$(pwd):$(pwd)/vendor
LDFLAGS="-linkmode=external" go build -o %{service_name}-proxy github.com/%{service_name}/libnetwork/cmd/proxy
popd

# build tini
pushd tini-%{commit_tini}
cmake .
make tini-static
popd

# build engine
pushd components/engine
mkdir _build
pushd _build
mkdir -p $(pwd)/src/github.com/%{service_name}
ln -s $(dirs +1 -l) src/github.com/%{service_name}/%{service_name}
ln -s $(dirs +1 -l) src/github.com/%{service_name}/%{service_name}
popd
export DOCKER_GITCOMMIT=%{shortcommit}
export DISABLE_WARN_OUTSIDE_CONTAINER=1 
DOCKER_DEBUG=1 GOPATH=$(pwd)/_build:$(pwd)/vendor:%{gopath} bash -x hack/make.sh dynbinary
popd

# DOCKER CLIENT
cd components/cli
mkdir -p src/github.com/%{service_name}/cli
ln -s $(pwd)/* src/github.com/%{service_name}/cli
export GOPATH=%{gopath}:$(pwd)
make VERSION=$(cat VERSION) GITCOMMIT=%{shortcommit} dynbinary # cli
mkdir -p ./man/man1
go build -buildmode=pie -o gen-manpages github.com/docker/cli/man
./gen-manpages --root "$(pwd)" --target "$(pwd)/man/man1"
./man/md2man-all.sh
cd ../..

%install
# install binaries
install -d %{buildroot}%{_bindir} 
install -p -m 755 components/cli/build/docker %{buildroot}%{_bindir}/docker
install -p -m 755 libnetwork-%{commit_libnetwork}/%{service_name}-proxy %{buildroot}%{_bindir}/%{service_name}-proxy
install -d %{buildroot}%{_sbindir} 
install -p -m 755 components/engine/bundles/dynbinary-daemon/dockerd %{buildroot}%{_sbindir}/dockerd

# Place to store images
install -d %{buildroot}%{_var}/cache/docker

pushd components/cli
# install manpages
install -d %{buildroot}%{_mandir}/man1
install -p -m 644 man/man1/*.1 %{buildroot}%{_mandir}/man1
install -d %{buildroot}%{_mandir}/man5
install -p -m 644 man/man5/*.5 %{buildroot}%{_mandir}/man5
install -d %{buildroot}%{_mandir}/man8
install -p -m 644 man/man8/*.8 %{buildroot}%{_mandir}/man8

# install bash completion
install -d %{buildroot}%{_sysconfdir}/bash_completion.d
install -p -m 644 contrib/completion/bash/docker %{buildroot}%{_sysconfdir}/bash_completion.d/docker.bash

# install fish completion
# create, install and own /usr/share/fish/vendor_completions.d until
# upstream fish provides it
install -dp %{buildroot}%{_datadir}/fish/vendor_completions.d
install -p -m 644 contrib/completion/fish/%{repo}.fish %{buildroot}%{_datadir}/fish/vendor_completions.d

# install container logrotate cron script
install -dp %{buildroot}%{_sysconfdir}/cron.daily/
install -p -m 755 %{SOURCE4} %{buildroot}%{_sysconfdir}/cron.daily/%{repo}-logrotate


# install zsh completion
install -d %{buildroot}%{_datadir}/zsh/site-functions
install -p -m 644 contrib/completion/zsh/_docker %{buildroot}%{_datadir}/zsh/site-functions


# for additional args
install -d %{buildroot}%{_sysconfdir}/sysconfig/
install -p -m 644 %{SOURCE2} %{buildroot}%{_sysconfdir}/sysconfig/%{repo}
install -p -m 644 %{SOURCE6} %{buildroot}%{_sysconfdir}/sysconfig/%{repo}-network
install -p -m 644 %{SOURCE3} %{buildroot}%{_sysconfdir}/sysconfig/%{repo}-storage
popd

# add vimfiles
install -dp %{buildroot}%{_datadir}/vim/vimfiles/doc
install -dp %{buildroot}%{_datadir}/vim/vimfiles/ftdetect
install -dp %{buildroot}%{_datadir}/vim/vimfiles/syntax
install -p -m 644 components/engine/contrib/syntax/vim/doc/%{service_name}file.txt %{buildroot}%{_datadir}/vim/vimfiles/doc/%{service_name}file.txt
install -p -m 644 components/engine/contrib/syntax/vim/ftdetect/%{service_name}file.vim %{buildroot}%{_datadir}/vim/vimfiles/ftdetect/%{service_name}file.vim
install -p -m 644 components/engine/contrib/syntax/vim/syntax/%{service_name}file.vim %{buildroot}%{_datadir}/vim/vimfiles/syntax/%{service_name}file.vim

# add nano files
install -dp %{buildroot}%{_datadir}/nano
install -p -m 644 components/engine/contrib/syntax/nano/Dockerfile.nanorc %{buildroot}%{_datadir}/nano/Dockerfile.nanorc

for cli_file in LICENSE MAINTAINERS NOTICE README.md; do
    cp "components/cli/$cli_file" "$(pwd)/cli-$cli_file"
done

# install tini
install -p -m 755 tini-%{commit_tini}/tini-static %{buildroot}%{_bindir}/%{service_name}-init

pushd components/engine
# install udev rules
install -d %{buildroot}%{_udevrulesdir}
install -p -m 755 contrib/udev/80-docker.rules %{buildroot}%{_udevrulesdir}
# install storage dir
install -d -m 700 %{buildroot}%{_libdir}/docker
# install systemd/init scripts
install -d %{buildroot}%{_unitdir}
install -p -m 644 %{SOURCE1} %{SOURCE7} %{buildroot}%{_unitdir}


install -d -m 0755 %{buildroot}%{_libdir}/docker-unit-test/
cp -pav Dockerfile %{buildroot}%{_libdir}/docker-unit-test/.
for d in api builder contrib daemon hack image integration-cli opts pkg registry runconfig vendor volume; do
  cp -a $d %{buildroot}%{_libdir}/docker-unit-test/
done
# remove docker.initd as it requires /sbin/runtime no packages in Fedora
rm -rf %{buildroot}%{_libdir}/docker-unit-test/contrib/init/openrc/docker.initd
popd
cp -pav VERSION %{buildroot}%{_libdir}/docker-unit-test/.

# sources
install -d -p %{buildroot}%{gopath}/src/%{import_path}
rm -rf pkg/symlink/testdata

# remove dirs that won't be installed in devel
rm -rf vendor docs _build bundles contrib/init hack project

# install sources to devel
for dir in */ ; do
    cp -rpav $dir %{buildroot}/%{gopath}/src/%{import_path}/
done

#network cleanup
install -d %{buildroot}%{_sbindir}
install -p -m 755 %{SOURCE8} %{buildroot}%{_sbindir}/docker-network-cleanup

%check
# This is completely unstable so I desactivate it for now.
#[ ! -w /run/%{repo}.sock ] || {
    #mkdir test_dir
    #pushd test_dir
    #git clone https://github.com/lsm5/docker.git -b fedora-1.10
    #pushd %{repo}
    #make test
    #popd
    #popd
#}

%pre
getent group docker > /dev/null || %{_sbindir}/groupadd -r docker
exit 0

%post
%systemd_post docker

%preun
%systemd_preun docker

%postun
%systemd_postun_with_restart docker

%files
%license cli-LICENSE components/engine/LICENSE
%doc components/engine/{AUTHORS,CHANGELOG.md,CONTRIBUTING.md,MAINTAINERS,NOTICE,README.md}
%doc cli-MAINTAINERS cli-NOTICE cli-README.md
%config(noreplace) %{_sysconfdir}/sysconfig/%{repo}
%config(noreplace) %{_sysconfdir}/sysconfig/%{repo}-network
%config(noreplace) %{_sysconfdir}/sysconfig/%{repo}-storage
%{_mandir}/man1/*.1*
%{_mandir}/man5/*.5*
%{_mandir}/man8/*.8*
%{_bindir}/docker
%{_bindir}/docker-proxy
%{_bindir}/docker-init
%dir %{_var}/cache/docker
%{_unitdir}/docker.service
%{_unitdir}/docker.socket
%dir %{_sysconfdir}/bash_completion.d
%{_sysconfdir}/bash_completion.d/docker.bash
%dir %{_libdir}/docker
%dir %{_udevrulesdir}
%{_udevrulesdir}/80-docker.rules
%{_sbindir}/docker-network-cleanup
%{_sbindir}/dockerd

%files devel
%dir %{gopath}/src/%{provider}.%{provider_tld}/%{project}
%{gopath}/src/%{import_path}

%files unit-test
%{_libdir}/docker-unit-test/

%files fish-completion
%dir %{_datadir}/fish/vendor_completions.d/
%{_datadir}/fish/vendor_completions.d/%{repo}.fish

%files logrotate
%doc README.%{repo}-logrotate
%{_sysconfdir}/cron.daily/%{repo}-logrotate

%files vim
%{_datadir}/vim/vimfiles/doc/%{repo}file.txt
%{_datadir}/vim/vimfiles/ftdetect/%{repo}file.vim
%{_datadir}/vim/vimfiles/syntax/%{repo}file.vim

%files zsh-completion
%{_datadir}/zsh/site-functions/_%{repo}

%files nano
%dir %{_datadir}/nano
%{_datadir}/nano/Dockerfile.nanorc


%changelog
* Tue Feb 05 2019 bcornec <bcornec> 18.06.1-1.2.mga6
+ Revision: 1363259
- Fix #24289 CVE-2018-20699 by applying upstream patch
- Fix mga#23749 by adding a requires on iptables
- Update to upstream 18.06.1 to fix mga#22201

* Wed May 31 2017 bcornec <bcornec> 17.03.1-4.mga6
+ Revision: 1105638
- Adds missing docker-proxy command to our docker package to solve network port redirection support missing since 1.12.

* Sat May 27 2017 neoclust <neoclust> 17.03.1-3.mga6
+ Revision: 1105096
- Rebuilf for ARM

* Thu May 11 2017 bcornec <bcornec> 17.03.1-2.mga6
+ Revision: 1100143
- Update to upstream docker 17.03

* Thu Jan 12 2017 bcornec <bcornec> 1.12.6-1.mga6
+ Revision: 1081154
- Update to upstream coker 1.12.6 fixes mga#20100

* Mon Jan 02 2017 bcornec <bcornec> 1.12.5-1.mga6
+ Revision: 1079627
- Updated to upstream docker 1.12.5

* Thu Nov 24 2016 bcornec <bcornec> 1.12.3-1.mga6
+ Revision: 1069584
- update to upstream docker 1.12.3

* Mon Oct 24 2016 bcornec <bcornec> 1.12.1-3.mga6
+ Revision: 1063373
- Add a dependency on aufs-tools for auplink needed in case of network setup

* Tue Sep 27 2016 blino <blino> 1.12.1-2.mga6
+ Revision: 1057105
- package docker-proxy (required by docker run)

* Sat Sep 24 2016 bcornec <bcornec> 1.12.1-1.mga6
+ Revision: 1055672
- Update to upstrea 0.12.1 docker
  - requires docker-container 0.2.3 and runc 1.1.0rc1
  - Now uses dockerd for the daemon part

* Fri Jul 22 2016 bcornec <bcornec> 1.11.2-1.mga6
+ Revision: 1043086
- Up date to upstream 1.11.2

* Mon Jun 13 2016 joequant <joequant> 1.11.1-6.mga6
+ Revision: 1021322
- move out cleanup script

* Fri Jun 10 2016 joequant <joequant> 1.11.1-5.mga6
+ Revision: 1021025
- absolute path for rm

* Wed Jun 01 2016 joequant <joequant> 1.11.1-4.mga6
+ Revision: 1019717
- Clean up veth files in sysconfig

* Mon May 23 2016 bcornec <bcornec> 1.11.1-3.mga6
+ Revision: 1017990
- Attempt to build docker for all arches

* Sun May 22 2016 bcornec <bcornec> 1.11.1-2.mga6
+ Revision: 1017708
-Up date docker to upstream 1.11.1. Now requires runC and containerd
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Mon Nov 23 2015 joequant <joequant> 1.9.1-1.mga6
+ Revision: 904986
- upgrade to 1.9.1

* Sat Nov 14 2015 joequant <joequant> 1.9.0-1.mga6
+ Revision: 903100
- update to 1.9.0

* Thu Oct 22 2015 joequant <joequant> 1.9.0-0.1.mga6
+ Revision: 894102
- upgrade to 1.9.0rc1

* Fri Aug 14 2015 joequant <joequant> 1.8.1-1.mga6
+ Revision: 864699
- upgrade to 1.8.1

* Sat Jul 25 2015 joequant <joequant> 1.7.1-1.mga6
+ Revision: 857171
- upgrade to 1.7.1

* Fri Jul 03 2015 joequant <joequant> 1.7.0-1.mga6
+ Revision: 849765
- upgrade to 1.7

* Wed May 27 2015 joequant <joequant> 1.6.2-1.mga6
+ Revision: 822759
- bump to 1.6.2 to fix mount /sys regression

* Sat May 09 2015 bcornec <bcornec> 1.6.1-1.mga5
+ Revision: 821564
- Update to upstream 1.6.1 to fix CVE-2015-3627, CVE-2015-3629, CVE-2015-3630, and CVE-2015-3631

* Mon Feb 23 2015 bcornec <bcornec> 1.5.0-1.mga5
+ Revision: 816686
- Update to upstream docker 1.5.0

* Fri Jan 23 2015 bcornec <bcornec> 1.4.1-2.mga5
+ Revision: 812005
- Build requires go-md2man now
- Adds Obsolete headers as per ML recommendations
- Update to upstream 1.4.1 and review build process fully. Now we use the go packages provided by docker to avoid compilation issues and mising features needed to have it work.
- Rename docker-io spec file into docker
- Rename docker-io pkg into docker

* Wed Oct 15 2014 umeabot <umeabot> 1.2.0-7.mga5
+ Revision: 745282
- Second Mageia 5 Mass Rebuild

* Mon Sep 29 2014 bcornec <bcornec> 1.2.0-6.mga5
+ Revision: 731806
- Add an upstream fix to support creation of tagged images with import

* Sun Sep 21 2014 bcornec <bcornec> 1.2.0-5.mga5
+ Revision: 712677
- Improve systemd integration for docker-io
- Improve systemd integration for docker-io

* Tue Sep 16 2014 umeabot <umeabot> 1.2.0-4.mga5
+ Revision: 678794
- Mageia 5 Mass Rebuild

* Wed Sep 10 2014 bcornec <bcornec> 1.2.0-3.mga5
+ Revision: 674527
- use gosrc macro to install ource in the std way (in parity with other golang modules)

* Wed Sep 10 2014 bcornec <bcornec> 1.2.0-2.mga5
+ Revision: 674517
- Fix docker to also deliver the new docker.socket systemd file

* Mon Sep 01 2014 bcornec <bcornec> 1.2.0-1.mga5
+ Revision: 670251
- Update to upstream docker 1.2.0

* Mon Aug 11 2014 bcornec <bcornec> 1.1.2-1.mga5
+ Revision: 661831
- Update to upstream 1.1.2

* Sat Jul 12 2014 bcornec <bcornec> 1.1.0-2.mga5
+ Revision: 651431
- Fix the patricia dep with the full name !
- Update docker-io deps (adding patricia)
- Update to upstream 1.1.0

* Wed Jul 02 2014 bcornec <bcornec> 0.12.0-1.mga5
+ Revision: 642365
- Again !
- and update the file location as well
- Fix udev rules in docker-io now installed using %%{_udevrulesdir}
- And libsqlite3-devel is also needed to build docker-io !
- Add a missing dep on golang(github.com/gorilla/context) for docker-io
- Upload first version of docker based on Fedora - no man pages yet as pandoc isn't ready
- Created package structure for docker-io.

